@@ -1,6 +1,7 @@
 #' @title Name chunks in a single file
 #'
-#' @description Name unnamed chunks in a single file using the filename with extension stripped as basis.
+#' @description Name unnamed chunks in a single file using the
+#' filename with extension stripped as basis.
 #'
 #' @details When using namer, please check the edits
 #'  before pushing them to your code base. Such automatic
@@ -10,6 +11,7 @@
 #'
 #' @template path
 #' @template unname
+#' @template prefix
 #'
 #' @export
 #'
@@ -23,7 +25,7 @@
 #' file.edit(temp_file_path)
 #' }
 #' file.remove(temp_file_path)
-name_chunks <- function(path, unname = FALSE){
+name_chunks <- function(path, unname = FALSE, prefix) {
   # read the whole file
   lines <- readLines(path)
 
@@ -31,7 +33,7 @@ name_chunks <- function(path, unname = FALSE){
   chunk_headers_info <- get_chunk_info(lines)
 
   # early exit if no chunk
-  if(is.null(chunk_headers_info)){
+  if (is.null(chunk_headers_info)) {
     return(invisible(TRUE))
   }
 
@@ -47,16 +49,17 @@ name_chunks <- function(path, unname = FALSE){
   # count unnamed chunks
   no_unnamed <- length(unique(unnamed$index))
 
-
   # act only if needed!
-  if(no_unnamed > 0){
-    # create new chunk names
-    filename <- fs::path_ext_remove(path)
-    filename <- fs::path_file(filename)
+  if (no_unnamed > 0) {
+    if (missing(prefix)) {
+      # create new chunk names
+      filename <- fs::path_ext_remove(path)
+      prefix <- fs::path_file(filename)
+    }
     # support for bookdown text references by removing underscores
     # https://bookdown.org/yihui/bookdown/markdown-extensions-by-bookdown.html#fnref5
-    filename <- clean_latex_special_characters(filename)
-    new_chunk_names <-  glue::glue("{filename}-{1:no_unnamed}")
+    prefix <- clean_latex_special_characters(prefix)
+    new_chunk_names <-  glue::glue("{prefix}-{1:no_unnamed}")
     new_chunk_names <- as.character(new_chunk_names)
     # and write to which line they correspond
     names(new_chunk_names) <- unique(unnamed$index)
@@ -65,7 +68,7 @@ name_chunks <- function(path, unname = FALSE){
     existing_names <- unique(chunk_headers_info$name)
     existing_names <- existing_names[!is.na(existing_names)]
 
-    if(any(new_chunk_names %in% existing_names)){
+    if (any(new_chunk_names %in% existing_names)) {
       new_chunk_names[new_chunk_names %in% existing_names] <-
         glue::glue("{new_chunk_names[new_chunk_names %in% existing_names]}-bis")
     }
@@ -84,7 +87,7 @@ name_chunks <- function(path, unname = FALSE){
 
     # re-get chunk names
     new_chunk_headers_info <- get_chunk_info(lines)
-    if(length(unique(new_chunk_headers_info$name)) != nrow(new_chunk_headers_info)){
+    if (length(unique(new_chunk_headers_info$name)) != nrow(new_chunk_headers_info)) {
       stop("Despite our efforts we'd be creating duplicate names.
 Had you run our script on your R Markdown before?
 Maybe namer::unname_chunks before running name_chunks.")
@@ -92,7 +95,7 @@ Maybe namer::unname_chunks before running name_chunks.")
 
     # save file
     writeLines(lines, path)
-}
+  }
   return(invisible(TRUE))
 }
 
@@ -125,7 +128,7 @@ Maybe namer::unname_chunks before running name_chunks.")
 #' file.edit(file.path(temp_dir,
 #'                    "examples", "example1.Rmd"))
 #' }
-name_dir_chunks <- function(dir, unname = FALSE){
+name_dir_chunks = function(dir, unname = FALSE) {
 
   if (isTRUE(unname)) {
     cli::cat_rule("Unnaming all chunks")
@@ -134,13 +137,13 @@ name_dir_chunks <- function(dir, unname = FALSE){
 
   cli::cat_rule("Naming all chunks")
 
-  rmds <- fs::dir_ls(dir, regexp = "*.[RrQq]md")
+  rmds = fs::dir_ls(dir, regexp = "*.[RrQq]md")
   purrr::walk(rmds, chatty_name_chunks)
 
   return(invisible(TRUE))
 }
 
-chatty_name_chunks <- function(path){
+chatty_name_chunks = function(path) {
   message(glue::glue("Scanning {path}..."))
   name_chunks(path)
 }
