@@ -25,6 +25,18 @@ test_that("renaming works", {
   file.remove(temp_file_path)
 })
 
+test_that("renaming with prefix works", {
+  temp_file_path <- file.path(tmp, "test.Rmd")
+
+  file.copy(system.file("examples", "example1.Rmd", package = "namer"),
+            temp_file_path)
+  name_chunks(temp_file_path, prefix = "my-prefix")
+  lines <- readLines(temp_file_path)
+  chunk_info <- get_chunk_info(lines)
+  expect_true(all(grepl("my-prefix", chunk_info$name[-1])))
+  file.remove(temp_file_path)
+})
+
 test_that("unnaming is advised when needed", {
   temp_file_path <- file.path(tmp, "example4.Rmd")
 
